| print.multifrailty_fit | R Documentation |
Provides standard print, summary, coef, vcov,
logLik, AIC, BIC, and confint S3 methods for objects
of class "multifrailty_fit".
## S3 method for class 'multifrailty_fit'
print(x, ...)
## S3 method for class 'multifrailty_fit'
summary(object, ...)
## S3 method for class 'summary.multifrailty_fit'
print(x, ...)
## S3 method for class 'multifrailty_fit'
coef(object, ...)
## S3 method for class 'multifrailty_fit'
vcov(object, ...)
## S3 method for class 'multifrailty_fit'
logLik(object, ...)
## S3 method for class 'multifrailty_fit'
AIC(object, ...)
## S3 method for class 'multifrailty_fit'
BIC(object, ...)
## S3 method for class 'multifrailty_fit'
confint(object, parm, level = 0.95, ...)
x |
An object of class |
... |
Additional arguments. |
object |
An object of class |
parm |
Optional parameter vector or names. |
level |
Confidence level for interval. Default 0.95. |
Formatted console output or numeric objects depending on method.
Pandey, A., Hanagal, D. D., & Tyagi, S. (2022). Shared Frailty Models Based on Cancer Data. International Journal of Statistics and Reliability Engineering, 9(3), 461-474.
Pandey, A., & Tyagi, S. (2021). Comparison of Multiplicative Frailty Models Under Weibull Baseline Distribution. Lobachevskii Journal of Mathematics, 42(13), 3184-3195.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.